@@ -958,6 +958,7 @@ void
 wnck_window_set_window_type (WnckWindow *window, WnckWindowType wintype)
 {
   Atom atom;
+  Display *display;
 
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
@@ -989,15 +990,18 @@ wnck_window_set_window_type (WnckWindow *window, WnckWindowType wintype)
   default:
     return;
   }
-  _wnck_error_trap_push ();
 
-  XChangeProperty (_wnck_window_get_display (window),
+  display = _wnck_window_get_display (window);
+
+  _wnck_error_trap_push (display);
+
+  XChangeProperty (display,
                    window->priv->xwindow,
                    _wnck_atom_get ("_NET_WM_WINDOW_TYPE"),
 		   XA_ATOM, 32, PropModeReplace,
 		   (guchar *)&atom, 1);
 
-  _wnck_error_trap_pop ();
+  _wnck_error_trap_pop (display);
 }
 
 /**
@@ -1168,16 +1172,44 @@ _wnck_window_get_startup_id (WnckWindow *window)
   return window->priv->startup_id;
 }
 
+/**
+ * wnck_window_get_class_group_name:
+ * @window: a #WnckWindow.
+ *
+ * Gets the class group name from the <ulink
+ * url="http://tronche.com/gui/x/icccm/sec-4.html&num;WM_CLASS">WM_CLASS Property</ulink>
+ * for @window.
+ *
+ * The class group name is also the identifier name of the #WnckClassGroup to
+ * which @window belongs.
+ *
+ * Return value: the class group name for @window, or %NULL if @window belongs
+ * to no class group.
+ **/
 const char*
-_wnck_window_get_resource_class (WnckWindow *window)
+wnck_window_get_class_group_name (WnckWindow *window)
 {
   g_return_val_if_fail (WNCK_IS_WINDOW (window), NULL);
 
   return window->priv->res_class;
 }
 
+/**
+ * wnck_window_get_class_instance_name:
+ * @window: a #WnckWindow.
+ *
+ * Gets the class instance name from the <ulink
+ * url="http://tronche.com/gui/x/icccm/sec-4.html&num;WM_CLASS">WM_CLASS Property</ulink>
+ * for @window.
+ *
+ * The class instance name allows to differentiate windows belonging to the
+ * same class group, so that they can use different resources.
+ *
+ * Return value: the class instance name for @window, or %NULL if @window has
+ * no class instance.
+ **/
 const char*
-_wnck_window_get_resource_name (WnckWindow *window)
+wnck_window_get_class_instance_name (WnckWindow *window)
 {
   g_return_val_if_fail (WNCK_IS_WINDOW (window), NULL);
 
@@ -3076,14 +3108,17 @@ update_wmclass (WnckWindow *window)
 static void
 update_wmhints (WnckWindow *window)
 {
+  Display  *display;
   XWMHints *hints;
 
   if (!window->priv->need_update_wmhints)
     return;
 
-  _wnck_error_trap_push ();
-  hints = XGetWMHints (_wnck_window_get_display (window), window->priv->xwindow);
-  _wnck_error_trap_pop ();
+  display = _wnck_window_get_display (window);
+
+  _wnck_error_trap_push (display);
+  hints = XGetWMHints (display, window->priv->xwindow);
+  _wnck_error_trap_pop (display);
 
   if (hints)
     {
